@@ -56,8 +56,6 @@
 #' @param nr.adapt            Number of iterations in the adaptation process, default is 1000. Some models may need more iterations during adptation.
 #' @param nr.burnin           Number of iteration discard for burn-in period, default is 1000. Some models may need a longer burnin period.
 #' @param nr.thin             Thinning rate, it must be a positive integer, the default value 1.
-#' @param be.quiet            Do not print warning message if the model does not adapt. The default value is FALSE. If you are not sure about the adaptation period choose be.quiet=TRUE.
-#'
 #' @return                    This function returns an object of the class "bcmixmeta". This object contains the MCMC
 #'                            output of each parameter and hyper-parameter in the model and
 #'                            the data frame used for fitting the model.
@@ -197,10 +195,7 @@ bcmixmeta = function(
     nr.iterations   = 10000,
     nr.adapt        = 1000,
     nr.burnin       = 1000,
-    nr.thin         = 1,
-    # Further options to link jags and R ...............................
-    be.quiet        = FALSE
-)UseMethod("bcmixmeta")
+    nr.thin         = 1)UseMethod("bcmixmeta")
 
 
 #' @export
@@ -227,9 +222,7 @@ bcmixmeta.default = function(
     nr.iterations   = 10000,
     nr.adapt        = 1000,
     nr.burnin       = 1000,
-    nr.thin         = 1,
-    # Further options to link jags and R ...............................
-    be.quiet        = FALSE
+    nr.thin         = 1
 )
 {
 
@@ -746,7 +739,8 @@ mu.new ~ dnorm(mu.0,  inv.var.0)
                    n.chains = nr.chains,
                    n.iter = nr.iterations,
                    n.burnin = nr.burnin,
-                   n.thin = nr.thin)
+                   n.thin = nr.thin,
+                   pD = TRUE)
 
   # Close text connection
   close(model.bugs.connection)
@@ -774,9 +768,9 @@ mu.new ~ dnorm(mu.0,  inv.var.0)
 }
 
 
-#' Generic print function for bcdpmeta object in jarbes.
+#' Generic print function for bcmixmeta object in jarbes.
 #'
-#' @param x The object generated by the function dpmmeta.
+#' @param x The object generated by the function bcmixmeta.
 #'
 #' @param digits The number of significant digits printed. The default value is 3.
 #'
